summaryrefslogtreecommitdiff
path: root/src/theory/quantifiers/expr_miner_manager.h
diff options
context:
space:
mode:
authorAndrew Reynolds <andrew.j.reynolds@gmail.com>2018-11-28 11:06:32 -0600
committerGitHub <noreply@github.com>2018-11-28 11:06:32 -0600
commite194e29c76f30ab9f0b42d20af699f132ef82fe4 (patch)
tree4423c9c8b63b3c0c16ef0948308bb8ebe3574e12 /src/theory/quantifiers/expr_miner_manager.h
parent4698209a407a18ec667a20983328a03d42095e40 (diff)
Generalize sygus stream solution filtering to logical strength (#2697)
Diffstat (limited to 'src/theory/quantifiers/expr_miner_manager.h')
-rw-r--r--src/theory/quantifiers/expr_miner_manager.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/src/theory/quantifiers/expr_miner_manager.h b/src/theory/quantifiers/expr_miner_manager.h
index d8e6ae651..d817d3775 100644
--- a/src/theory/quantifiers/expr_miner_manager.h
+++ b/src/theory/quantifiers/expr_miner_manager.h
@@ -71,8 +71,10 @@ class ExpressionMinerManager
void enableRewriteRuleSynth();
/** enable query generation (--sygus-query-gen) */
void enableQueryGeneration(unsigned deqThresh);
- /** filter implied solutions (--sygus-sol-filter-implied) */
- void enableFilterImpliedSolutions();
+ /** filter strong solutions (--sygus-filter-sol=strong) */
+ void enableFilterStrongSolutions();
+ /** filter weak solutions (--sygus-filter-sol=weak) */
+ void enableFilterWeakSolutions();
/** add term
*
* Expression miners may print information on the output stream out, for
@@ -92,8 +94,8 @@ class ExpressionMinerManager
bool d_doRewSynth;
/** whether we are doing query generation */
bool d_doQueryGen;
- /** whether we are filtering implied candidates */
- bool d_doFilterImplied;
+ /** whether we are filtering solutions based on logical strength */
+ bool d_doFilterLogicalStrength;
/** the sygus function passed to initializeSygus, if any */
Node d_sygus_fun;
/** whether we are using sygus types */
@@ -106,8 +108,8 @@ class ExpressionMinerManager
CandidateRewriteDatabase d_crd;
/** query generator */
QueryGenerator d_qg;
- /** solution filter */
- SolutionFilter d_solf;
+ /** solution filter based on logical strength */
+ SolutionFilterStrength d_sols;
/** sygus sampler object */
SygusSampler d_sampler;
/** extended rewriter object */
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback